@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007,2010-2012 Guido Guenther <agx@sigxcpu.org>
+# (C) 2006,2007,2010-2012,2015 Guido Guenther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -101,6 +101,7 @@ class GbpOptionParser(OptionParser):
                  'sign-tags'       : 'False',
                  'force-create'    : 'False',
                  'no-create-orig'  : 'False',
+                 'cleaner'         : '/bin/true',
                  'keyid'           : '',
                  'posttag'         : '',
                  'postbuild'       : '',
@@ -124,6 +125,7 @@ class GbpOptionParser(OptionParser):
                  'ignore-branch'   : 'False',
                  'meta'            : 'True',
                  'meta-closes'     : 'Closes|LP',
+                 'meta-closes-bugnum'  : r'(?:bug|issue)?\#?\s?\d+',
                  'full'            : 'False',
                  'id-length'       : '0',
                  'git-author'      : 'False',
@@ -143,8 +145,11 @@ class GbpOptionParser(OptionParser):
                  'customizations'  : '',
                  'spawn-editor'    : 'release',
                  'patch-numbers'   : 'True',
+                 'patch-num-format': '%04d-',
+                 'renumber'        : 'False',
                  'notify'          : 'auto',
                  'merge'           : 'True',
+                 'merge-mode'      : 'merge',
                  'track'           : 'True',
                  'author-is-committer': 'False',
                  'author-date-is-committer-date': 'False',
@@ -208,6 +213,8 @@ class GbpOptionParser(OptionParser):
                   "Parse meta tags in commit messages, default is '%(meta)s'",
              'meta-closes':
                   "Meta tags for the bts close commands, default is '%(meta-closes)s'",
+             'meta-closes-bugnum':
+                  "Meta bug number format, default is '%(meta-closes-bugnum)s'",
              'ignore-new':
                   "Build with uncommited changes in the source tree, default is '%(ignore-new)s'",
              'ignore-branch':
@@ -251,12 +258,22 @@ class GbpOptionParser(OptionParser):
              'patch-numbers':
                   ("Whether to number patch files, "
                    "default is %(patch-numbers)s"),
+             'patch-num-format':
+                  ("The format specifier for patch number prefixes, "
+                   "default is %(patch-num-format)s"),
+             'renumber':
+                  ("Whether to renumber patches exported from patch queues, "
+                   "instead of preserving the number specified in "
+                   "'Gbp-Pq: Name' tags, default is %(renumber)s"),
              'notify':
                   ("Whether to send a desktop notification after the build, "
                    "default is '%(notify)s'"),
              'merge':
                   ("After the import merge the result to the debian branch, "
                    "default is '%(merge)s'"),
+             'merge-mode':
+                  ("Howto merge the new upstream sources onto the debian branch"
+                   "default is '%(merge-mode)s'"),
              'track':
                   ("Set up tracking for remote branches, "
                    "default is '%(track)s'"),
@@ -564,7 +581,6 @@ class GbpOptionParserDebian(GbpOptionParser):
     defaults = dict(GbpOptionParser.defaults)
     defaults.update( {
                        'builder'            : 'debuild -i -I',
-                       'cleaner'            : '/bin/true',
                      } )
 
 
@@ -578,7 +594,13 @@ class GbpOptionParserRpm(GbpOptionParser):
             'vendor'                    : 'Downstream',
             'packaging-branch'          : 'master',
             'packaging-dir'             : '',
+            'packaging-tag-msg'         : ('%(pkg)s (vendor)s release '
+                                                         '%(version)s'),
             'packaging-tag'             : 'packaging/%(version)s',
+            'export-sourcedir'          : 'SOURCES',
+            'export-specdir'            : 'SPECS',
+            'export-dir'                : '../rpmbuild',
+            'builder'                   : 'rpmbuild',
             'spec-file'                 : '',
                     })
 
@@ -599,9 +621,19 @@ class GbpOptionParserRpm(GbpOptionParser):
             'packaging-tag':
                 "Format string for packaging tags, RPM counterpart of the "
                 "'debian-tag' option, default is '%(packaging-tag)s'",
+            'packaging-tag-msg':
+               ("Format string for packaging tag messages, "
+                "default is '%(packaging-tag-msg)s'"),
             'spec-file':
                 "Spec file to use, causes the packaging-dir option to be "
                 "ignored, default is '%(spec-file)s'",
+            'export-sourcedir':
+                "Subdir (under EXPORT_DIR) where packaging sources (other than "
+                "the spec file) are exported, default is "
+                "'%(export-sourcedir)s'",
+            'export-specdir':
+                "Subdir (under EXPORT_DIR) where package spec file is "
+                "exported default is '%(export-specdir)s'",
                  })
 
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
