@@ -20,6 +20,7 @@
 from six.moves import configparser
 import errno
 import os, os.path
+import shutil
 import sys
 import time
 import gbp.deb as du
@@ -29,6 +30,7 @@ from gbp.command_wrappers import (Command,
 from gbp.config import (GbpOptionParserDebian, GbpOptionGroup)
 from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
 from gbp.deb.source import DebianSource, DebianSourceError
+from gbp.deb.format import DebianSourceFormat
 from gbp.format import format_str
 from gbp.git.vfs import GitVfs
 from gbp.deb.upstreamsource import DebianUpstreamSource
@@ -176,7 +178,7 @@ def extract_orig(orig_tarball, dest_dir):
     upstream = DebianUpstreamSource(orig_tarball)
     upstream.unpack(dest_dir)
 
-    # Check if tarball extracts into a single folder or not:
+    # Check if tarball extracts into a single folder:
     if upstream.unpacked != dest_dir:
         # If it extracts a single folder, move its contents to dest_dir:
         gbp.log.debug("Moving %s to %s" % (upstream.unpacked, dest_dir))
@@ -185,6 +187,15 @@ def extract_orig(orig_tarball, dest_dir):
         os.rmdir(dest_dir)
         os.rename(tmpdir, dest_dir)
 
+    # Remove debian/ from unpacked upstream tarball in case of non 1.0 format
+    underlay_debian_dir = os.path.join(dest_dir, 'debian')
+    format_file = os.path.join('debian', 'source', 'format')
+    if os.path.exists(underlay_debian_dir) and os.path.exists(format_file):
+        format = DebianSourceFormat.parse_file(format_file)
+        if format.version in ['2.0', '3.0']:
+            gbp.log.info("Removing debian/ from unpacked upstream source at %s" % underlay_debian_dir)
+            shutil.rmtree(underlay_debian_dir)
+
 #}
 
 def source_vfs(repo, options, tree):
@@ -328,6 +339,14 @@ def guess_comp_type(repo, comp_type, cp, tarball_dir):
     return comp_type
 
 
+def check_tag(options, repo, source):
+    """Perform specified consistency checks on git history"""
+    tag = repo.version_to_tag(options.debian_tag, source.changelog.version)
+    if (options.tag or options.tag_only) and not options.retag:
+        if repo.has_tag(tag):
+            raise GbpError("Tag '%s' already exists" % tag)
+
+
 def get_pbuilder_dist(options, repo, native=False):
     """
     Determin the dist to build for with pbuilder/cowbuilder
@@ -457,9 +476,9 @@ def build_parser(name, prefix=None):
     cmd_group.add_config_file_option(option_name="cleaner", dest="cleaner",
                       help="command to clean the working copy, default is '%(cleaner)s'")
     cmd_group.add_config_file_option(option_name="prebuild", dest="prebuild",
-                      help="command to run before a build, default is '%(prebuild)s'")
+                      help="hook to run before a build, default is '%(prebuild)s'")
     cmd_group.add_config_file_option(option_name="postexport", dest="postexport",
-                      help="command to run after exporting the source tree, default is '%(postexport)s'")
+                      help="hook to run after exporting the source tree, default is '%(postexport)s'")
     cmd_group.add_config_file_option(option_name="postbuild", dest="postbuild",
                       help="hook run after a successful build, default is '%(postbuild)s'")
     cmd_group.add_config_file_option(option_name="posttag", dest="posttag",
@@ -566,6 +585,9 @@ def main(argv):
         head = repo.head
         tree = write_tree(repo, options)
         source = source_vfs(repo, options, tree)
+
+        check_tag(options, repo, source)
+
         if not options.tag_only:
             output_dir = prepare_output_dir(options.export_dir)
             tarball_dir = options.tarball_dir or output_dir
@@ -613,7 +635,11 @@ def main(argv):
             if options.prebuild:
                 Hook('Prebuild', options.prebuild, shell=True,
                      extra_env={'GBP_GIT_DIR': repo.git_dir,
-                                'GBP_BUILD_DIR': build_dir})(dir=build_dir)
+                                'GBP_BUILD_DIR': build_dir,
+                                'GBP_PBUILDER_DIST': get_pbuilder_dist(options,
+                                                                       repo,
+                                                                       source.is_native()),
+                                })(dir=build_dir)
 
             setup_pbuilder(options, repo, source.is_native())
             # Finally build the package:
