@@ -49,7 +49,7 @@ def parse_args(argv):
 
 
 def parse_cmd_config(command):
-    """Make a command parse it's config files"""
+    """Make a command parse its config files"""
     parser = GbpOptionParser(command)
     parser.parse_config_files()
     return parser
@@ -68,6 +68,8 @@ def print_cmd_single_value(query, printer):
 
     parser = parse_cmd_config(cmd)
     value = parser.get_config_file_value(option)
+    if value is None:
+        value = ''
     printer("%s=%s" % (query, value))
     return 0 if value else 1
 
@@ -82,7 +84,7 @@ def print_cmd_all_values(cmd, printer):
     if not cmd:
         return 2
     try:
-        # Populae the parset to get a list of
+        # Populate the parser to get a list of
         # valid options
         module = import_command(cmd)
         parser = module.build_parser(cmd)
@@ -91,8 +93,7 @@ def print_cmd_all_values(cmd, printer):
 
     for option in parser.valid_options:
         value = parser.get_config_file_value(option)
-        if value != '':
-            printer("%s.%s=%s" % (cmd, option, value))
+        printer("%s.%s=%s" % (cmd, option, value))
     return 0
 
 
